const config = require('config');
const BizResult = require('./BizResult')
const BizResultCode = require('./BaseResultCode');
const logger = require('./logger')('ProxyController.js');
const request = require('sync-request');

const proxyConfig = config.get('proxyConfig');
const timeout = proxyConfig.get('timeout');

class ProxyController {

    /**
     * proxy HTTP
     * @param {*} req       HTTP request
     * @param {*} res       HTTP response
     * @returns 
     */
    static async proxyHttp(req, res) {

        // GET, POST, PUT, DELETE, PATCH
        var type = req.body.type;
        var ip = req.body.ip;
        var port = req.body.port;
        var path = req.body.path;
        var headers = req.headers;
        var param = req.body.param;
        var body = req.body;

        if (!type || !ip || !path) {
            res.send(BizResult.validateFailed());
            return;
        }

        var url;
        if (!port) {
            port = '';
            url = 'http://' + ip + path;
        }
        else {
            url = 'http://' + ip + ':' + port + path;
        }
        if (param) {
            param = '?' + param
        } else {
            param = ''
        }

        try {
            var httpRes;
            if (type == 'GET') {
                httpRes = JSON.parse(request(type, url + param).getBody('utf-8'));
            }
            else if (type == 'POST') {
                if (headers) {
                    httpRes = JSON.parse(request(type, url, {
                        timeout: timeout,
                        // headers: headers,
                        json: body
                    }).getBody('utf-8'));
                }
                else {
                    httpRes = JSON.parse(request(type, url, {
                        timeout: timeout,
                        json: body
                    }).getBody('utf-8'));
                }
            }

            res.send(BizResult.success(httpRes));
            return;
        } catch (error) {
            logger.error("http request error:{}", error);
            res.send(BizResult.fail(BizResultCode.SERVICE_UNAVAILABLE));
            return;
        }
    }
}
module.exports = ProxyController